#!/usr/bin/env python

# Currently only tested with Python3
from __future__ import print_function


# For more info on the CrossRef API, see:
#   https://www.crossref.org/documentation/retrieve-metadata/rest-api/a-non-technical-introduction-to-our-api/
#
# The default DOI value used below is based on the one given in the CrossRef documentation

import os
import sys
import json

import argparse

import requests
import urllib.parse

import util

base_url = "https://api.crossref.org"
search_work_url = base_url+"/works/"


# JSON is returned by default by CrossRef, but let's be explicit!
headers = {
    'Content-type': 'application/json'
}


def getDOI(doi):
    
    query_url  = search_work_url + urllib.parse.quote_plus(doi)

    print("query_url="+query_url)

    # Based on:
    #    https://stackoverflow.com/questions/25491090/how-to-use-python-to-execute-a-curl-command    
    response = requests.get(query_url, headers=headers)

    returned_json_str = response.content
    returned_json     = json.loads(returned_json_str)

    return returned_json


        
if __name__ == "__main__":

    parser = argparse.ArgumentParser()

    parser.add_argument('doi', nargs='?')
    parser.add_argument('output-file.json', nargs='?')
    
    args = parser.parse_args()
    
    doi = getattr(args,'doi');
    if (doi == None):
        # CrossRef Example
        crossref_example_doi = "10.1155/2014/413629"
                
        # Bainbridge et al example, IJDL user-centric approach ...
        stinky_doi = "10.1145/1998076.1998084"
    
        print("As a default, selecting CrossRef example DOI: " + crossref_example_doi)
        doi = crossref_example_doi

    json_output_filename = getattr(args,'output-file.json');
    if (json_output_filename == None):
        encoded_doi = urllib.parse.quote_plus(doi)        
        json_output_filename = "crossref-"+encoded_doi+".json"
    
    returned_json = getDOI(doi)

    util.writeJSON(json_output_filename,returned_json)

